@@ -103,6 +103,8 @@ from .extfields import (
     EmailAddress,
 )
 
+from .subclass import SubClass
+
 from .errors import standard_readable_error_for_typedpy_exception, ErrorInfo
 
 from .utility import get_list_type, type_is_generic
@@ -111,4 +113,6 @@ from .mappers import mappers, Deleted, Constant, DoNotSerialize
 
 from .versioned_mapping import convert_dict, Versioned
 
-from .commons import nested, deep_get
+from .commons import nested, deep_get, first_in, flatten
+
+from .keysof import keys_of
\ No newline at end of file
